%define anolis_release 2
%global major_version 5.4
# Normally, this is the same as version, but... not always.
%global test_version 5.4.6

Name:           lua
Version:        %{major_version}.6
Release:        %{anolis_release}%{?dist}
Summary:        Powerful light-weight programming language
License:        MIT
URL:            http://www.lua.org/
Source0:        http://www.lua.org/ftp/lua-%{version}.tar.gz
# copied from doc/readme.html on 2014-07-18
Source1:        mit.txt
Source3:        http://www.lua.org/tests/lua-%{test_version}-tests.tar.gz
Source4:        luaconf.h

Patch0001:      0001-lua-5.4.4-autotoolize.patch
Patch0002:      0002-add-rules-to-autoconfig-luaconf.h-to-make-sure-luaco.patch

BuildRequires:  automake autoconf libtool readline-devel ncurses-devel
BuildRequires:  make
Requires:       lua-libs = %{version}-%{release}

%description
Lua is a powerful light-weight programming language designed for
extending applications. Lua is also frequently used as a
general-purpose, stand-alone language. Lua is free software.
Lua combines simple procedural syntax with powerful data description
constructs based on associative arrays and extensible semantics. Lua
is dynamically typed, interpreted from bytecodes, and has automatic
memory management with garbage collection, making it ideal for
configuration, scripting, and rapid prototyping.

%package doc
Summary:        Documentation files for %{name}
Requires:       %{name} = %{version}-%{release}
BuildArch:      noarch

%description    doc
The %{name}-doc package contains documentation files for %{name}.

%package devel
Summary:        Development files for %{name}
Requires:       %{name} = %{version}-%{release}
# The RPM related dependencies bring nothing to a non-RPM Lua developer
# But we want them when packages BuildRequire lua-devel
Requires:       (lua-rpm-macros if rpm-build)

%description devel
This package contains development files for %{name}.

%package libs
Summary:        Libraries for %{name}
Provides:       lua(abi) = %{major_version}

%description libs
This package contains the shared libraries for %{name}.

%package static
Summary:        Static library for %{name}
Requires:       %{name} = %{version}-%{release}

%description static
This package contains the static version of liblua for %{name}.


%prep
%setup -q -a 3
cp %{SOURCE1} .
mv src/luaconf.h src/luaconf.h.template.in
%patch0001 -p1
%patch0002 -p1
autoreconf -ifv

%build
%configure --with-readline --with-compat-module

sed -i 's|@pkgdatadir@|%{_datadir}|g' src/luaconf.h.template

# hack so that only /usr/bin/lua gets linked with readline as it is the
# only one which needs this and otherwise we get License troubles
%make_build LIBS="-lm -ldl"
# only /usr/bin/lua links with readline now #luac_LDADD="liblua.la -lm -ldl"

%check
cd ./lua-%{test_version}-tests/

# Removing tests that fail under mock/koji
sed -i.orig -e '
    /db.lua/d;
    /errors.lua/d;
    ' all.lua
LD_LIBRARY_PATH=$RPM_BUILD_ROOT/%{_libdir} $RPM_BUILD_ROOT/%{_bindir}/lua -e"_U=true" all.lua

%install
%make_install
mkdir -p $RPM_BUILD_ROOT%{_libdir}/lua/%{major_version}
mkdir -p $RPM_BUILD_ROOT%{_datadir}/lua/%{major_version}

# Rename luaconf.h to luaconf-<arch>.h to avoid file conflicts on
# multilib systems and install luaconf.h wrapper
mv %{buildroot}%{_includedir}/luaconf.h %{buildroot}%{_includedir}/luaconf-%{_arch}.h
install -p -m 644 %{SOURCE4} %{buildroot}%{_includedir}/luaconf.h

%generate_compatibility_deps

%files
%license mit.txt

%doc doc/*.html doc/*.css doc/*.gif doc/*.png
%{_bindir}/lua
%{_bindir}/luac
%{_mandir}/man1/lua*.1*

%files doc
%doc README

%files libs
%dir %{_libdir}/lua
%dir %{_libdir}/lua/%{major_version}
%{_libdir}/liblua-%{major_version}.so
%dir %{abidir}
%{abidir}/liblua-%{major_version}.dump
%dir %{_datadir}/lua
%dir %{_datadir}/lua/%{major_version}

%files devel
%{_includedir}/l*.h
%{_includedir}/l*.hpp
%{_libdir}/liblua.so
%{_libdir}/pkgconfig/*.pc

%files static
%{_libdir}/*.a

%changelog
* Mon Sep 4 2023 Jingyun Hua <huajingyun@loongson.cn> - 5.4.6-2
- Support loongarch64

* Sun May 14 2023 Funda Wang <fundawang@yeah.net> - 5.4.6-1
- New version 5.4.6

* Sat Apr 29 2023 Funda Wang <fundawang@yeah.net> - 5.4.5-1
- New version 5.4.5

* Fri Feb 24 2023 Feng Su <sufeng@linux.alibaba.com> - 5.4.4-4
- add abi/api files

* Sat Oct 08 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 5.4.4-3
- add doc package

* Sun Apr 24 2022 Chunmei Xu <xuchunmei@linux.alibaba.com> - 5.4.4-2
- add rule to autoconfig to make sure luaconf.h has defined macros

* Wed Mar  9 2022 Liwei Ge <liwei.glw@linux.alibaba.com> - 5.4.4-1
- Init version from upstream v5.4.4
